"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChainTransactionMigrator = void 0;
const ChainTransaction_js_1 = require("../../businessObjects/versioned/ChainTransaction.js");
const EVMTransaction_js_1 = require("../../businessObjects/versioned/EVMTransaction.js");
const SolanaTransaction_js_1 = require("../../businessObjects/versioned/SolanaTransaction.js");
const SuiTransaction_js_1 = require("../../businessObjects/versioned/SuiTransaction.js");
const VersionedObject_js_1 = require("../../businessObjects/versioned/VersionedObject.js");
const index_js_1 = require("../../configuration/index.js");
const index_js_2 = require("../../enum/index.js");
class ChainTransactionMigrator extends VersionedObject_js_1.VersionedObjectMigrator {
    getCurrentVersion() {
        return ChainTransaction_js_1.ChainTransaction.CURRENT_VERSION;
    }
    factory(data) {
        switch ((0, index_js_1.getChainInfoByChainId)(data.chain).chainTechnology) {
            case index_js_2.EChainTechnology.Solana: {
                const solanaTransaction = data;
                return new SolanaTransaction_js_1.SolanaTransaction(solanaTransaction.chainId, solanaTransaction.hash, solanaTransaction.timestamp, solanaTransaction.slot, solanaTransaction.err, solanaTransaction.memo, solanaTransaction.measurementDate);
            }
            case index_js_2.EChainTechnology.EVM: {
                const evmTransaction = data;
                return new EVMTransaction_js_1.EVMTransaction(evmTransaction.chain, evmTransaction.hash, evmTransaction.timestamp, evmTransaction.blockHeight, evmTransaction.to, evmTransaction.from, evmTransaction.value, evmTransaction.gasPrice, evmTransaction.contractAddress, evmTransaction.input, evmTransaction.methodId, evmTransaction.functionName, evmTransaction.events, evmTransaction.measurementDate);
            }
            case index_js_2.EChainTechnology.Sui: {
                const suiTransaction = data;
                return new SuiTransaction_js_1.SuiTransaction(suiTransaction.chain, suiTransaction.hash, suiTransaction.timestamp, suiTransaction.to, suiTransaction.from, suiTransaction.value, suiTransaction.gasPrice, suiTransaction.contractAddress, suiTransaction.input, suiTransaction.methodId, suiTransaction.functionName, null, // TODO: fix whatever is going on with events
                suiTransaction.measurementDate);
            }
            default:
                throw new Error("chain ID does not match known technology");
        }
    }
    getUpgradeFunctions() {
        return new Map();
    }
}
exports.ChainTransactionMigrator = ChainTransactionMigrator;
//# sourceMappingURL=ChainTransactionMigrator.js.map