"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EarnedRewardMigrator = void 0;
const DirectReward_js_1 = require("../../businessObjects/rewards/DirectReward.js");
const EarnedReward_js_1 = require("../../businessObjects/rewards/EarnedReward.js");
const LazyReward_js_1 = require("../../businessObjects/rewards/LazyReward.js");
const Web2Reward_js_1 = require("../../businessObjects/rewards/Web2Reward.js");
const VersionedObject_js_1 = require("../../businessObjects/versioned/VersionedObject.js");
const ERewardType_js_1 = require("../../enum/ERewardType.js");
class EarnedRewardMigrator extends VersionedObject_js_1.VersionedObjectMigrator {
    getCurrentVersion() {
        return EarnedReward_js_1.EarnedReward.CURRENT_VERSION;
    }
    factory(data) {
        switch (data.type) {
            case ERewardType_js_1.ERewardType.Web2: {
                const web2Reward = data;
                return new Web2Reward_js_1.Web2Reward(web2Reward.queryCID, web2Reward.name, web2Reward.image, web2Reward.description, web2Reward.url, web2Reward.credentialType, web2Reward.credential, web2Reward.instructions);
            }
            case ERewardType_js_1.ERewardType.Direct: {
                const directReward = data;
                return new DirectReward_js_1.DirectReward(directReward.queryCID, directReward.name, directReward.image, directReward.description, directReward.chainId, directReward.contractAddress, directReward.recipientAddress);
            }
            case ERewardType_js_1.ERewardType.Lazy: {
                const lazyReward = data;
                return new LazyReward_js_1.LazyReward(lazyReward.queryCID, lazyReward.name, lazyReward.image, lazyReward.description, lazyReward.chainId, lazyReward.contractAddress, lazyReward.recipientAddress, lazyReward.functionName, lazyReward.functionParams);
            }
            default:
                throw new Error(`Factory not implemented for ${data.type}`);
        }
    }
    getUpgradeFunctions() {
        return new Map();
    }
}
exports.EarnedRewardMigrator = EarnedRewardMigrator;
//# sourceMappingURL=EarnedRewardMigrator.js.map